echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Recommended
[[ $(command -v gi-inspect-typelib) == "" ]] && echo "Installing glib" && extension --install glib && echo "Finished glib"
# Optional
if [[ $INSTALL_OPTIONAL != false ]]; then 
	[[ $(command -v gtkdocize) == "" ]] && echo "Installing gtk_doc" && extension --install gtk_doc && echo "Finished gtk_doc"
fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v mbimcli) == "" ]]; then
	echo "libmbim" 										>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "libmbim" 										>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
